You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@xerces.apache.org by mu...@apache.org on 2009/06/09 14:54:47 UTC

svn commit: r782983 - /xerces/java/branches/xml-schema-1.1-dev/src/org/apache/xerces/xni/parser/XMLAssertHandler.java

Author: mukulg
Date: Tue Jun  9 12:54:47 2009
New Revision: 782983

URL: http://svn.apache.org/viewvc?rev=782983&view=rev
Log:
improvements as per comments from Khaled Noaman

Modified:
    xerces/java/branches/xml-schema-1.1-dev/src/org/apache/xerces/xni/parser/XMLAssertHandler.java

Modified: xerces/java/branches/xml-schema-1.1-dev/src/org/apache/xerces/xni/parser/XMLAssertHandler.java
URL: http://svn.apache.org/viewvc/xerces/java/branches/xml-schema-1.1-dev/src/org/apache/xerces/xni/parser/XMLAssertHandler.java?rev=782983&r1=782982&r2=782983&view=diff
==============================================================================
--- xerces/java/branches/xml-schema-1.1-dev/src/org/apache/xerces/xni/parser/XMLAssertHandler.java (original)
+++ xerces/java/branches/xml-schema-1.1-dev/src/org/apache/xerces/xni/parser/XMLAssertHandler.java Tue Jun  9 12:54:47 2009
@@ -23,12 +23,11 @@
 import org.apache.xerces.xni.XMLString;
 
 /**
- * The implementation of this interface will invoke an external XPath engine, which
- * would evaluate the XPath 2.0 expressions, in XML Schema 1.1 assertions.
+ * The implementation of this interface will invoke an external XPath engine, that
+ * would evaluate the XPath 2.0 expressions, for XML Schema 1.1 assertions.
  * This interface communicates with the XMLSchemaValidator, and accepts information
  * required by the external XPath engine. If assertions evaluation returns 'true',
- * validation would proceed further. And while upon assertion failure, validation process 
- * terminates in the implementing classes if this interface.
+ * validation would proceed further.
  * 
  * @author Mukul Gandhi, IBM
  * @author Ken Cai, IBM
@@ -45,10 +44,10 @@
      *             XML element
      * @param attributes
      *             attributes of the element
-     * @param assertObject
-     *             An object holding the assertions for this element (for the element's type)                                    
+     * @param augs
+     *             Augmentations object                                    
      */
-    public void startElement(QName element, XMLAttributes attributes, Object assertObject);
+    public void startElement(QName element, XMLAttributes attributes, Augmentations augs);
     
     /*
      * A callback method triggered during endElement method call in, XMLSchemaValidator
@@ -56,7 +55,7 @@
      * @param element
      *           XML element  
      * @param augs
-     *           Augmentations object, to support Schema types          
+     *           Augmentations object        
      */
     public void endElement(QName element, Augmentations augs) throws Exception;
         
@@ -70,26 +69,26 @@
 
   
     /**
-     * Allows the user to set specific attributes on the underlying
+     * Allows the user to set specific properties on the underlying
      * implementation.
      * @param name The name of the attribute.
      * @param value The value of the attribute.
      * @exception IllegalArgumentException thrown if the underlying
      * implementation doesn't recognize the attribute.
      */
-    public void setAttribute(String name, Object value)
+    public void setProperty(String name, Object value)
                 throws IllegalArgumentException;
     
     
     /**
-     * Allows the user to retrieve specific attributes on the underlying
+     * Allows the user to retrieve specific properties on the underlying
      * implementation.
      * @param name The name of the attribute.
      * @return value The value of the attribute.
      * @exception IllegalArgumentException thrown if the underlying
      * implementation doesn't recognize the attribute.
      */
-    public abstract Object getAttribute(String name)
+    public abstract Object getProperty(String name)
                 throws IllegalArgumentException;
 
 }



---------------------------------------------------------------------
@@ -70,26 +69,26 @@
      * implementation.
-     * @param name The name of the attribute.
-     * @param value The value of the attribute.
+     * @param name The name of the property.
+     * @param value The value of the property.
      * @exception IllegalArgumentException thrown if the underlying
@@ -70,26 +69,26 @@
      * @exception IllegalArgumentException thrown if the underlying
-     * implementation doesn't recognize the attribute.
+     * implementation doesn't recognize the property.
      */
@@ -70,26 +69,26 @@
      * implementation.
-     * @param name The name of the attribute.
-     * @return value The value of the attribute.
+     * @param name The name of the property.
+     * @return value The value of the property.
      * @exception IllegalArgumentException thrown if the underlying
@@ -70,26 +69,26 @@
      * @exception IllegalArgumentException thrown if the underlying
-     * implementation doesn't recognize the attribute.
+     * implementation doesn't recognize the property.
      */
To unsubscribe, e-mail: commits-unsubscribe@xerces.apache.org
For additional commands, e-mail: commits-help@xerces.apache.org